<template>
  <div id="chart-container" :style="{width:width,height:height}">
  </div>
</template>

<script>
import { rtuTotalAlarmAnalysis } from '@/cpx_sewage/api/operationManage/rtuMonitor'
import * as echarts from 'echarts'
export default {
  name: 'SingleLineChart',
  props: {
    width: {
      type: String,
      default: '100%'
    },
    height: {
      type: String,
      default: '350px'
    },
    chartData: {
      type: Object,
      default: () => {}
    }
  },
  data() {
    return {
      chart: null
    }
  },
  watch: {
    chartData: {
      immediate: true,
      deep: true,
      handler(newVal, oldVal) {
        if (this.chart) {
          if (newVal) {
            this.setOptions(newVal)
          } else {
            this.setOptions(oldVal)
          }
        }
      }
    }
  },
  mounted() {
    this.initChart()
    if (this.chart) {
      window.addEventListener('resize', this.$_handleResizeChart)
    }
  },
  beforeDestroy() {
    if (!this.chart) {
      return false
    }
    this.chart.dispose()
    this.chart = null
    window.removeEventListener('resize', this.$_handleResizeChart)
  },
  methods: {
    $_handleResizeChart() {
      this.chart.resize()
    },
    async setOptions({ time, Data, config } = {}) {
      // prettier-ignore
      const res = await rtuTotalAlarmAnalysis({ })
      const data = res.data
      const dateList = data.map(function(item) {
        return item.report_time
      })
      const valueList = data.map(function(item) {
        return item.alarmCount
      })
      const option = {
        // Make gradient line here
        tooltip: {
          show: true,
          trigger: 'axis',
          axisPointer: {
            type: 'cross',
            label: {
              backgroundColor: '#6a7985'
            }
          }
        },
        xAxis: {
          type: 'category',
          data: dateList,
          // 设置x轴的数据和刻度线对齐
          boundaryGap: false
        },
        yAxis: {
          // 取消Y轴的轴线
          axisLine: {
            show: false
          },
          type: 'value'
        },
        series: [{
          name: '累计报警数量 (次)',
          type: 'line',
          showSymbol: false, // 取消折线上面的点
          // eslint-disable-next-line standard/array-bracket-even-spacing
          data: valueList,
          itemStyle: {
            normal: {
              color: new echarts.graphic.LinearGradient(0, 0, 0, 1,
                [{ offset: 1, color: '#fabb5c' }, { offset: 0.3, color: '#f99331' }, { offset: 0.5, color: '#da6518' }, { offset: 0.2, color: 'red' }])
            }
          }

        }] }

      this.chart.setOption(option)
    },
    // 表格初始化
    initChart() {
      this.chart = echarts.init(this.$el)
      // 渲染表格
      this.setOptions(this.chartData)
    }
  }
}
</script>

<style>
* {
  margin: 0;
  padding: 0;
}
#chart-container {
  position: relative;
  height: 100vh;
  overflow: hidden;
}
</style>